.. classes

Classes
=======

The ``emdfile`` classes enable (1) :doc:`wrapping data <data>` with a name, units, and calibrations, (2) easily building, saving, and reading :doc:`filetree-like heirarchies <tree>`, and (3) flexibly including arbitrary :doc:`metadata <metadata>`.

.. toctree::
   :maxdepth: 2
   :caption: Links:

   Data <data.rst>
   Metadata <metadata.rst>
   Trees <tree.rst> 

